#!/opt/cloudlinux/venv/bin/python3

# Copyright (c) Cloud Linux GmbH & Cloud Linux Software, Inc 2010-2018 All Rights Reserved
#
# Licensed under CLOUD LINUX LICENSE AGREEMENT
# http://cloudlinux.com/docs/LICENSE.TXT

import logging
import subprocess
import hashlib
import os

logging.basicConfig(format='%(asctime)s %(message)s', datefmt='%m/%d/%Y %I:%M:%S %p',
                    filename='/usr/share/lve/modlscapi/plesk_upd_hook.log',level=logging.DEBUG)
PLESK_DEFAULT_DOMAIN = '/usr/local/psa/admin/conf/templates/default/domain/domainVirtualHost.php'
PLESK_CUSTOM_DOMAIN = '/usr/local/psa/admin/conf/templates/custom/domain/domainVirtualHost.php'


def match_hash():
    """
    Check if stored hash matches domainVirtualHost.php file
    :param target_file:
    :return: True or False
    """
    try:
        with open('/usr/share/lve/modlscapi/plesk_domain_md5', 'r') as md5sum:
            orig_sum = md5sum.read().strip()
    except Exception as e:
        logging.error('Failed to read stored hash: %s' % e)
        orig_sum = None
    return hashlib.md5(open(PLESK_DEFAULT_DOMAIN, 'rb').read()).hexdigest() == orig_sum


def run():
    """
    Run switch_mod_lsapi --setup command
    """
    logging.info('Run switch_mod_lsapi --setup!')
    try:
        output = subprocess.check_output(["/usr/bin/switch_mod_lsapi", "--setup"],
                                         stderr=subprocess.STDOUT,
                                         text=True)
        logging.info('Output was: %s' % output)
    except subprocess.CalledProcessError as e:
        logging.info('FAILED: {0} with {1}'.format(e.returncode, e.output))


# for patch_installed event
# upd = os.getenv('NEW_PATCH_VERSION')
# logging.info('Update detected: %s' % upd)

# for plesk_component_upgrade event
comp = os.getenv('OLD_PLESK_COMPONENT_NAME')
logging.info('Component updated: %s' % comp)
if not match_hash():
    logging.info('domainVirtualHost.php hash do not match')
    run()
    with open('/usr/share/lve/modlscapi/plesk_domain_md5', 'w') as md5sum:
        md5sum.write(hashlib.md5(open(PLESK_DEFAULT_DOMAIN, 'rb').read()).hexdigest())
elif not os.path.exists(PLESK_CUSTOM_DOMAIN):
    logging.info('No custom domainVirtualHost.php found')
    run()
else:
    logging.info('domainVirtualHost.php hash did not changed')
    logging.info('switch_mod_lsapi --setup will not be run')
