#!/bin/bash
# Copyright © Cloud Linux GmbH & Cloud Linux Software, Inc 2010-2021 All Rights Reserved
#
# Licensed under CLOUD LINUX LICENSE AGREEMENT
# http://cloudlinux.com/docs/LICENSE.TXT

# RPM:
# $1 == 1 -- upgrade
# $1 == 0 -- uninstall

# DEB:
# $1 == remove/upgrade

# "mod_lsapi PRE UNINSTALL STARTED"

g_path=/usr/share/lve/modlscapi/
rhel=$2

function check_usage() {
      HANDLER=$1
      STR=$2
      if [ -n "$STR" ]; then
          if [ -z "$(echo "$STR" | grep "is not used")" ]; then
              echo "mod_lsapi can't be uninstalled while $HANDLER handler is used by domains"
              echo "Please check /usr/local/psa/bin/php_handler --get-usage -id $HANDLER"
              echo ""
              exit 1
          fi
      fi
    }


if [[ "$1" == 0 || $1 == "remove" ]]; then
  if [[ $rhel -lt 7 ]]; then
      /sbin/service lsapi-cache stop > /dev/null 2>&1
      /sbin/chkconfig --del lsapi-cache
  else
      systemctl --no-reload disable lsapi-cache.service > /dev/null 2>&1
      systemctl stop lsapi-cache.service > /dev/null 2>&1
  fi
fi

case "$1" in
    remove | 0)

    if [ -x /usr/local/psa/bin/php_handler ]; then
      echo "Checking for Plesk LSPHP handlers, it may take some time..."
      STR=$(/usr/local/psa/bin/php_handler --get-usage -id x-httpd-lsphp-custom)
      check_usage x-httpd-lsphp-custom "$STR"
      STR=$(/usr/local/psa/bin/php_handler --get-usage -id x-httpd-lsphp-56)
      check_usage x-httpd-lsphp-56 "$STR"
      STR=$(/usr/local/psa/bin/php_handler --get-usage -id x-httpd-lsphp-70)
      check_usage x-httpd-lsphp-70 "$STR"
      STR=$(/usr/local/psa/bin/php_handler --get-usage -id x-httpd-lsphp-71)
      check_usage x-httpd-lsphp-71 "$STR"
      STR=$(/usr/local/psa/bin/php_handler --get-usage -id x-httpd-lsphp-72)
      check_usage x-httpd-lsphp-72 "$STR"
      STR=$(/usr/local/psa/bin/php_handler --get-usage -id x-httpd-lsphp-73)
      check_usage x-httpd-lsphp-73 "$STR"
      STR=$(/usr/local/psa/bin/php_handler --get-usage -id x-httpd-lsphp-74)
      check_usage x-httpd-lsphp-74 "$STR"
      STR=$(/usr/local/psa/bin/php_handler --get-usage -id x-httpd-lsphp-80)
      check_usage x-httpd-lsphp-80 "$STR"
      STR=$(/usr/local/psa/bin/php_handler --get-usage -id x-httpd-lsphp-81)
      check_usage x-httpd-lsphp-81 "$STR"
      STR=$(/usr/local/psa/bin/php_handler --get-usage -id x-httpd-lsphp-82)
      check_usage x-httpd-lsphp-82 "$STR"
      STR=$(/usr/local/psa/bin/php_handler --get-usage -id x-httpd-lsphp-83)
      check_usage x-httpd-lsphp-83 "$STR"
      STR=$(/usr/local/psa/bin/php_handler --get-usage -id x-httpd-lsphp-44)
      check_usage x-httpd-lsphp-44 "$STR"
      STR=$(/usr/local/psa/bin/php_handler --get-usage -id x-httpd-lsphp-51)
      check_usage x-httpd-lsphp-51 "$STR"
      STR=$(/usr/local/psa/bin/php_handler --get-usage -id x-httpd-lsphp-52)
      check_usage x-httpd-lsphp-52 "$STR"
      STR=$(/usr/local/psa/bin/php_handler --get-usage -id x-httpd-lsphp-53)
      check_usage x-httpd-lsphp-53 "$STR"
      STR=$(/usr/local/psa/bin/php_handler --get-usage -id x-httpd-lsphp-54)
      check_usage x-httpd-lsphp-54 "$STR"
      STR=$(/usr/local/psa/bin/php_handler --get-usage -id x-httpd-lsphp-55)
      check_usage x-httpd-lsphp-55 "$STR"
      switch_mod_lsapi --uninstall
    fi

    if [ -e /usr/share/lve/modlscapi/global.enabled ]; then
      rm -rf /usr/share/lve/modlscapi/global.enabled
    fi
    "${g_path}"user/install-mod_lsapi.py --delete

    ;;

    abort-upgrade|abort-remove|abort-deconfigure)
    ;;

    *)
        echo "prerm called with unknown argument \`$1'" >&2
        exit 1
    ;;
esac

# "mod_lsapi PRE UNINSTALL FINISHED"
